
version 17.0
set varabbrev on

/* Open Data */

/* before running, change the folder path "C:\Users\wb282057\OneDrive - WBG\Documents\AFR_INF_DR\Labor_Stat\MDG\accessibility_measures\OpenData" to "your folder" */


/* using LSMS Antananarivo 2016 */
global path   "C:/WBG/rep-checks/RR_MDG_2025_389"
global output "${path}/outputs"

log using "${output}/log.txt", text replace
use "${path}/s1_hhroster.dta", clear

keep ea_id dwllid Id s1_motherinhh-s1_scpfather
keep if Id==1
drop Id
save "${path}/HH_chara_temp.dta", replace
use "${path}/s1_hhroster.dta", clear
generate HHSIZE=1
generate N5YrBelow=(s1_age<=5)
generate N6_15Yr=(s1_age>=6&s1_age<=15)
generate N60YrAbove=(s1_age>=60)
generate N_Workers= (s3_lbrsyr7==1)
collapse (sum) HHSIZE N5YrBelow N6_15Yr N60YrAbove N_Workers, by(ea_id dwllid)
save "${path}/Tana_HH_chara.dta", replace

use "${path}/s1_hhroster.dta", clear
joinby ea_id dwllid using "${path}/HH_chara_temp.dta", update unmatched(master)
drop _m
joinby ea_id dwllid using "${path}/Tana_HH_chara.dta", unmatched(master)
drop _m
joinby dwllid using "${path}/spatial_data.dta", unmatched(master)
drop _m
destring C_CODE_BNG C_CODE, replace

generate dWork=(s3_lbrsyr7==1) if !missing(s3_lbrsyr7)
generate AGE=s1_age
generate FEMALE=(s1_gndr==2)
label define gender_lab 0 "MALE" 1 "FEMALE"
label values FEMALE gender_lab
generate dMarried=(s1_mrtlst==1|s1_mrtlst==2|s1_mrtlst==3|s1_mrtlst==4|s1_mrtlst==5)
mvdecode s2_hghstgrade, mv(-98 -96)
generate dPriEdu=(s2_hghstgrade==2) if !missing(s2_hghstgrade)
generate dSecEdu=(s2_hghstgrade>=3& s2_hghstgrade<=7) if !missing(s2_hghstgrade)
generate dTerEdu=(s2_hghstgrade>=8& s2_hghstgrade<=12) if !missing(s2_hghstgrade)
generate N_OtherWorkers=N_Workers-dWork
generate d1N_OtherWorkers=(N_Workers-dWork>=1) if !missing(N_OtherWorkers)
generate MIN1=s3_lbrtme   /* commute time (min) */
replace MIN1=0 if s3_lbrtme==.& dWork==0
replace MIN1=. if MIN1>180
sum KM_CBD   /* straight line km to CBD */
sum MIN_CBD  /* minutes to CBD */
generate MIN_BUS=min(MtoTaxibe, MtoSubUBus)/1000/4*60   /* meter to the nearest bus route, divided by 4km/h */
sum w_MIN_BUZ  /* weighted minutes to "business areas" based on JICA map: sum min_ij * weight_j for household i to go to business area j */
sum w_MIN_ALL  /* weighted minutes to all buildings based on Open Buildings: sum min_ij * weight_j for household i to go to built area j */


/* figures */

/* figure 3 */
hist MIN1 if AGE>=16&AGE<=64, bin(15) xtitle("Commute time one way (minutes)") scale(1.4)
graph export "${output}/fig3.png", replace

/* figure 4 */
generate COST1=s3_lbrcst
replace COST1=0 if s3_lbrcst==.& dWork==0
hist COST1 if AGE>=16&AGE<=64, bin(15) xtitle("Commuting costs one way (Ariary)") scale(1.4)
graph export "${output}/fig4.png", replace

/* figure 5 */
generate dWalk2W=(s3_lbrtmn==1) if !missing(s3_lbrtmn)
generate dBike=(s3_lbrtmn==2) if !missing(s3_lbrtmn)
generate dCar=(s3_lbrtmn==3) if !missing(s3_lbrtmn)
generate dMicrobus_Taxi=(s3_lbrtmn>=4&s3_lbrtmn<=6) if !missing(s3_lbrtmn)
generate dMinibus=(s3_lbrtmn==7) if !missing(s3_lbrtmn)
graph bar dWalk2W dBike dCar dMicrobus_Taxi dMinibus, percentage stack legend(label(1 "Walk") label(2 "Bicycle") label(3 "Car") label(4 "Microbus & Taxi") label(5 "Minibus") size(medlarge) rows(2)) over(FEMALE, relabel(1 "Male" 2 "Female") label(labsize(medium))) ytitle("Modal share to go to a workplace" "(%, multiple answers)", size(medlarge)) ylabel(, labsize(medlarge)) blabel(bar, position(center) format(%9.1f) color(white) size(medium))
graph export "${output}/fig5.png", replace

/* figure 6 */
generate MtoBus=MIN_BUS/60*4*1000
hist MtoBus if Id==1, bin(15) xtitle("Distance to the nearest bus route (meter)") scale(1.4)
graph export "${output}/fig6.png", replace

/* figure 7 */
hist MIN_CBD if Id==1, bin(15) xtitle("Travel time to CBD (minute)") scale(1.4)
graph export "${output}/fig7.png", replace


/* accessibility averages: Table 1 */
sum MIN1 if AGE>=16&AGE<=64
sum MIN_BUS KM_CBD MIN_CBD w_MIN_BUZ w_MIN_ALL if Id==1

/* correlation: Table 2 */
cor MIN1 MIN_BUS KM_CBD MIN_CBD w_MIN_BUZ w_MIN_ALL if AGE>=16&AGE<=64


/* baseline probit: Table 4 */
foreach _w of varlist MIN1 MIN_BUS KM_CBD MIN_CBD w_MIN_BUZ w_MIN_ALL {
probit dWork `_w' FEMALE AGE dPriEdu dSecEdu dTerEdu dMarried HHSIZE N_OtherWorkers N5YrBelow N6_15Yr N60YrAbove i.C_CODE_BNG if AGE>=16&AGE<=64, vce(robust) nolog
margins, dydx(`_w')
}

/* linear probit IV: Table 5 */
foreach _w of varlist MIN1 MIN_BUS KM_CBD MIN_CBD w_MIN_BUZ w_MIN_ALL {
ivregress gmm dWork (`_w'= elev_m temp_jan prec_jan) FEMALE AGE dPriEdu dSecEdu dTerEdu dMarried HHSIZE N_OtherWorkers N5YrBelow N6_15Yr N60YrAbove i.C_CODE_BNG if AGE>=16&AGE<=64, vce(robust)
sum dWork `_w' if e(sample)   /* for summary statistics: Table 3 */
estat endogenous
estat first
estat overid
margins, dydx(`_w')
}
generate _sample=(e(sample))
sum dWork FEMALE AGE dPriEdu dSecEdu dTerEdu dMarried HHSIZE N_OtherWorkers N5YrBelow N6_15Yr N60YrAbove elev_m temp_jan prec_jan i.C_CODE_BNG if e(sample)    /* for summary statistics: Table 3 */

/* IV Probit: Table 6 */
foreach _w of varlist MIN1 MIN_BUS KM_CBD MIN_CBD w_MIN_BUZ w_MIN_ALL {
ivprobit dWork (`_w'= elev_m temp_jan prec_jan) FEMALE AGE dPriEdu dSecEdu dTerEdu dMarried HHSIZE N_OtherWorkers N5YrBelow N6_15Yr N60YrAbove i.C_CODE_BNG if AGE>=16&AGE<=64, vce(robust) nolog
margins, dydx(`_w') predict(pr)
}

/* Refutability test */
foreach _w of varlist MIN1 MIN_BUS KM_CBD MIN_CBD w_MIN_BUZ w_MIN_ALL {
local _X "FEMALE AGE dPriEdu dSecEdu dTerEdu dMarried HHSIZE N_OtherWorkers N5YrBelow N6_15Yr N60YrAbove i.C_CODE_BNG"
local _Z "elev_m temp_jan prec_jan"
local _W `_w' 
ivprobit dWork (`_W' = `_Z') `_X' if AGE>=16&AGE<=64& _sample==1, nolog
display `: word count `_Z''
local _K = `: word count `_Z''
display `: word count `_W''
local _L = `: word count `_W''
local _df=`_K'-`_L'
local i=1
foreach _end of varlist `_W' {
generate _w`i'=`_end'
local i=`i'+1
}
foreach i of numlist 1/`_L' {
regress _w`i' `_Z' `_X' if AGE>=16&AGE<=64& _sample==1, vce(robust)
predict u_`i', residual
}
probit dWork u_1 `_W' `_X' if AGE>=16&AGE<=64& _sample==1, nolog
ereturn list
local ll_cf1=e(ll)
estimates store CF_1
predict _xb_hat, xb
constraint 1 _b[_xb_hat]=1
probit dWork _xb_hat `_Z' if AGE>=16&AGE<=64& _sample==1, nolog constraints(1)
local ll_cf2b=e(ll)
estimates store CF_2b
lrtest CF_2b CF_1, force stat df(`_df')
display as text "Modified Refutability test stat = " as result -2*(`ll_cf1'-`ll_cf2b')
display as text "chi2 10% =" as result invchi2(`_df', 0.9)              /* p value for test stat at 10% significance */
display as text "chi2  5% =" as result invchi2(`_df', 0.95)             /*                           5%              */
display as text "chi2  1% =" as result invchi2(`_df', 0.99)             /*                           1%              */
drop u_* _w* _xb_hat
}

cap log close
